Stan Math Library: stan/math/prim/mat/fun/diagonal.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

diagonal.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_DIAGONAL_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_DIAGONAL_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
15 template <typename T>
16 inline
17 Eigen::Matrix<T, Eigen::Dynamic, 1>
18 diagonal(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m) {
19 return m.diagonal();
20 }
21
22 }
23 }
24 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::diagonal
Eigen::Matrix< T, Eigen::Dynamic, 1 > diagonal(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
Return a column vector of the diagonal elements of the specified matrix.
Definition: diagonal.hpp:18
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.